HideBlizzard = LibStub('AceAddon-3.0'):NewAddon('HideBlizzard', 'AceConsole-3.0', 'AceEvent-3.0')
local CURRENT_VERSION = GetAddOnMetadata('HideBlizzard', 'Version')

local defaults = {
	profile = {
		modules = {
			ActionBar = false,
			Buttons = false,
			Pet = false,
			Player = false,
			SpecialFrames = false,
			Target = false,
			Vehicle = false,
		},
	},
}

function HideBlizzard:OnInitialize()
	self.db = LibStub('AceDB-3.0'):New('HideBlizzardDB', defaults)

	do
		local timer, t = nil, 0
		function HideBlizzard:UpdateConfig()
			for k, v in self:IterateModules() do
				if v:IsEnabled() then
					v:Disable()
					v:Enable()
				end
			end
		end
		local function update()
			t = t + arg1
			if t > 0.5 then
				timer:SetScript('OnUpdate', nil)
				HideBlizzard:UpdateConfig()
			end
		end
		function HideBlizzard:OnProfileUpdate()
			t = 0
			timer = timer or CreateFrame('Frame', nil, UIParent)
			timer:SetScript('OnUpdate', update)
		end
	end
end

function HideBlizzard:OnEnable()
	self:RegisterEvent('PLAYER_REGEN_DISABLED', function()
		if InterfaceOptionsFrame:IsVisible() then
			self:Print('Cannot configure settings while in combat. Closing options window.')
			InterfaceOptionsFrame:Hide()
		end
	end)

	do
		if self.db.profile.welcome then
			message('An old version of HideBlizzard has been detected. You will need to ReloadUI for HideBlizzard to function properly.')
			HideBlizzardDB = nil
		end

		if not self.db.profile.Welcome and not self.db.profile.welcome then
			self:WelcomeDialog()
			self.db.profile.Welcome = true
			self.db.profile.Version = CURRENT_VERSION
		end

		if self.db.profile.Version ~= CURRENT_VERSION then
			if not self.db.profile.Welcome and not self.db.profile.Version then
				return
			else
				self.db.profile.Version = CURRENT_VERSION
				self:Print(format('Updated to version %s', self.db.profile.Version))
			end
		end

		for k, v in self:IterateModules() do
			if self.db.profile.modules[k] ~= false then
				v:Enable()
			end
		end
	end

	do
		function HideBlizzard:Cmd(args)
			local cmd = string.split(' ', args):lower() or args:lower()
			local loaded, reason = LoadAddOn('HideBlizzardOptions')
			if cmd == 'config' then
				if not loaded then
					if reason == 'DISABLED' then
						self:Print('Error loading HideBlizzard option frame: DISABLED')
					else
						return
					end
				else
					LoadAddOn('HideBlizzardOptions')
					self:RegisterOptions()
					InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.Profiles)
					InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.HideBlizzard)
				end
				InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.Profiles)
				InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.HideBlizzard)
			elseif cmd == 'help' then
				self:HelpDialog()
			elseif cmd == 'version' then
				self:Print(self.db.profile.Version)
			else
				self:ShowHelp()
			end
		end

		function HideBlizzard:ShowHelp(cmd)
			local function PrintCmd(cmd, desc)
				DEFAULT_CHAT_FRAME:AddMessage(format(' - |cff40bbff%s|r: %s', cmd, desc))
			end
			self:Print('Commands: /hb | /hideblizzard')
			PrintCmd('config', 'open the configuration panel')
			PrintCmd('help', 'open the help window')
			PrintCmd('version', 'prints the current version')
		end
	end

	self:RegisterChatCommand('hb', 'Cmd')
	self:RegisterChatCommand('hideblizzard', 'Cmd')
	self.db.RegisterCallback(self, 'OnProfileChanged', 'OnProfileUpdate')
	self.db.RegisterCallback(self, 'OnProfileCopied', 'OnProfileUpdate')
	self.db.RegisterCallback(self, 'OnProfileReset', 'OnProfileUpdate')
end

function HideBlizzard:OnDisable()
end