-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('Vehicle', 'AceEvent-3.0')
mod.modName = 'Vehicle |cffEE2C2CBeta|r'

local options = {
	vehiclebuttons = {
		type = 'toggle',
		name = 'Vehicle Buttons',
		width = 'full',
		get = function() return mod.db.profile.vehiclebuttons end,
		set = function(info, v)
			mod.db.profile.vehiclebuttons = v
			if v then
				mod:EnableVehicleButtons()
			else
				mod:DisableVehicleButtons()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Vehicle end,
	},
	vehicleseat = {
		type = 'toggle',
		name = 'Vehicle Seat', 
		width = 'full',
		get = function() return mod.db.profile.vehicleseat end,
		set = function(info, v)
			mod.db.profile.vehicleseat = v
			if v then
				mod:EnableVehicleSeat()
			else
				mod:DisableVehicleSeat()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Vehicle end,
	},
}

local defaults = {
	profile = {
		vehiclebuttons = false,
		vehicleseat = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Vehicle', defaults)
end

function mod:OnEnable()
	self:UpdateFrames()
end

function mod:OnDisable()
	self:DisableVehicleButtons()
	self:DisableVehicleSeat()
end

function mod:UpdateFrames()
	if mod.db.profile.vehiclebuttons == true then
		self:EnableVehicleButtons()
	else
		self:DisableVehicleButtons()
	end
	if mod.db.profile.vehicleseat == true then
		self:EnableVehicleSeat()
	else
		self:DisableVehicleSeat()
	end
end

function mod:EnableVehicleButtons()
	VehicleMenuBar:UnregisterAllEvents()
	VehicleMenuBarPitchUpButton:Hide()
	VehicleMenuBarPitchDownButton:Hide()
	VehicleMenuBarLeaveButton:Hide()
end

function mod:DisableVehicleButtons()
	VehicleMenuBarPitchUpButton:Show()
	VehicleMenuBarPitchDownButton:Show()
	VehicleMenuBarLeaveButton:Show()
	VehicleMenuBar:RegisterEvent('UNIT_ENTERED_VEHICLE')
	VehicleMenuBar:RegisterEvent('VEHICLE_ANGLE_UPDATE')
end

function mod:EnableVehicleSeat()
	VehicleSeatIndicator:UnregisterAllEvents()
	VehicleSeatIndicator:Hide()
end

function mod:DisableVehicleSeat()
	VehicleSeatIndicator:Show()
	VehicleSeatIndicator:RegisterEvent('UNIT_ENTERED_VEHICLE')
	VehicleSeatIndicator:RegisterEvent('PLAYER_GAINS_VEHICLE_DATA')
	VehicleSeatIndicator:RegisterEvent('UNIT_ENTERING_VEHICLE')
	VehicleSeatIndicator:RegisterEvent('VEHICLE_PASSENGERS_CHANGED')
	VehicleSeatIndicator:RegisterEvent('UNIT_EXITED_VEHICLE')
	VehicleSeatIndicator:RegisterEvent('PLAYER_LOSES_VEHICLE_DATA')
	VehicleSeatIndicator:RegisterEvent('PLAYER_ENTERING_WORLD')
end

function mod:Info()
	return 'Hides vehicle related frames.'
end

function mod:GetOptions()
	return options
end